@@ -32,4 +32,6 @@
     --- 修改了窗口靠边功能的导入方式
          原来的导入方式: from PyQtGuiLib.core.pullOver import PullOver
          现在的导入方式: from PyQtGuiLib.core import PullOver
+2022.12.26  0.0.6.0版本
+    --- 新增轮播组件,2022.12.22  已经基本完成,可能还存在BUG,以后修改(测试发布)
 '''
\ No newline at end of file
