@@ -14,7 +14,8 @@ if PYQT_VERSIONS == "PyQt5":
         QPropertyAnimation,
         QThread,
         QEasingCurve,
-        QByteArray
+        QByteArray,
+        QSequentialAnimationGroup
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -31,7 +32,8 @@ if PYQT_VERSIONS == "PyQt6":
         QPropertyAnimation,
         QThread,
         QEasingCurve,
-        QByteArray
+        QByteArray,
+        QSequentialAnimationGroup
     )
 
 if PYQT_VERSIONS == "PySide2":
@@ -48,7 +50,8 @@ if PYQT_VERSIONS == "PySide2":
         QPropertyAnimation,
         QThread,
         QEasingCurve,
-        QByteArray
+        QByteArray,
+        QSequentialAnimationGroup
     )
 if PYQT_VERSIONS == "PySide6":
     from PySide6.QtCore import (
@@ -64,5 +67,6 @@ if PYQT_VERSIONS == "PySide6":
         QPropertyAnimation,
         QThread,
         QEasingCurve,
-        QByteArray
+        QByteArray,
+        QSequentialAnimationGroup
     )
\ No newline at end of file
